==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/entity/SpellEntity.java <==
package com.github.thedeathlycow.frostiful.entity;

import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1668;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2394;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_2487;
import net.minecraft.class_2520;
import net.minecraft.class_3966;
import org.jetbrains.annotations.Nullable;

public abstract class SpellEntity extends class_1668 {

    private static final String AMPLIFIER_NBT_KEY = "EffectAmplifier";
    private static final String MAX_DISTANCE_NBT_KEY = "MaxDistance";
    private double maxDistance = Double.POSITIVE_INFINITY;
    @Nullable
    private class_243 startPosition = null;

    public SpellEntity(class_1299<? extends SpellEntity> type, class_1937 world, class_1309 owner, class_243 velocity) {
        this(type, world, owner, velocity, Double.POSITIVE_INFINITY);
    }

    public SpellEntity(class_1299<? extends SpellEntity> type, class_1937 world, class_1309 owner, class_243 velocity, double maxDistance) {
        super(type, owner, velocity, world);
        this.maxDistance = maxDistance;
        this.method_60949(owner.method_33571(), this.method_36454(), this.method_36455());
    }

    protected SpellEntity(class_1299<? extends SpellEntity> entityType, class_1937 world) {
        super(entityType, world);
    }

    protected abstract void applyEffectCloud();

    public void method_5773() {
        super.method_5773();

        if (!method_37908().field_9236 && this.method_5805()) {
            if (this.startPosition == null) {
                this.startPosition = this.method_19538();
            }

            double distTravelledSqd = this.startPosition.method_1025(this.method_19538());
            if (distTravelledSqd > this.maxDistance * this.maxDistance) {
                this.applyEffectCloud();
            }
        }
    }

    @Override
    public void method_7454(class_3966 hitResult) {
        super.method_7454(hitResult);
        if (!method_37908().field_9236 && this.method_5805()) {
            this.applyEffectCloud();
        }
    }

    public void method_5652(class_2487 nbt) {
        super.method_5652(nbt);
        nbt.method_10549(MAX_DISTANCE_NBT_KEY, this.maxDistance);
    }

    public void method_5749(class_2487 nbt) {
        super.method_5749(nbt);

        if (nbt.method_10573(MAX_DISTANCE_NBT_KEY, class_2520.field_33256)) {
            this.maxDistance = nbt.method_10574(MAX_DISTANCE_NBT_KEY);
        }
    }

    protected void method_7488(class_239 hitResult) {
        super.method_7488(hitResult);
        if (!method_37908().field_9236) {
            this.applyEffectCloud();
        }
    }

    @Override
    protected class_2394 method_7467() {
        return class_2398.field_28013;
    }

    @Override
    protected float method_7466() {
        return 1.0f;
    }

    @Override
    protected boolean method_7468() {
        return false;
    }


}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/entity/SpellEntity.java <==
package com.github.thedeathlycow.frostiful.entity;

import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1668;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2394;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_3966;
import org.jetbrains.annotations.Nullable;

public abstract class SpellEntity extends class_1668 {

    private static final String AMPLIFIER_NBT_KEY = "EffectAmplifier";
    private static final String MAX_DISTANCE_NBT_KEY = "MaxDistance";
    private double maxDistance = Double.POSITIVE_INFINITY;
    @Nullable
    private class_243 startPosition = null;

    public SpellEntity(class_1299<? extends SpellEntity> type, class_1937 world, class_1309 owner, class_243 velocity) {
        this(type, world, owner, velocity, Double.POSITIVE_INFINITY);
    }

    public SpellEntity(class_1299<? extends SpellEntity> type, class_1937 world, class_1309 owner, class_243 velocity, double maxDistance) {
        super(type, owner, velocity, world);
        this.maxDistance = maxDistance;
        this.method_60949(owner.method_33571(), this.method_36454(), this.method_36455());
    }

    protected SpellEntity(class_1299<? extends SpellEntity> entityType, class_1937 world) {
        super(entityType, world);
    }

    protected abstract void applyEffectCloud();

    public void method_5773() {
        super.method_5773();

        if (!method_37908().field_9236 && this.method_5805()) {
            if (this.startPosition == null) {
                this.startPosition = this.method_19538();
            }

            double distTravelledSqd = this.startPosition.method_1025(this.method_19538());
            if (distTravelledSqd > this.maxDistance * this.maxDistance) {
                this.applyEffectCloud();
            }
        }
    }

    @Override
    public void method_7454(class_3966 hitResult) {
        super.method_7454(hitResult);
        if (!method_37908().field_9236 && this.method_5805()) {
            this.applyEffectCloud();
        }
    }

    public void method_5652(class_11372 writeView) {
        super.method_5652(writeView);
        if (!Double.isInfinite(this.maxDistance)) {
            writeView.method_71463(MAX_DISTANCE_NBT_KEY, this.maxDistance);
        }
    }

    public void method_5749(class_11368 readView) {
        super.method_5749(readView);
        this.maxDistance = readView.method_71422(MAX_DISTANCE_NBT_KEY, Double.POSITIVE_INFINITY);
    }

    protected void method_7488(class_239 hitResult) {
        super.method_7488(hitResult);
        if (!method_37908().field_9236) {
            this.applyEffectCloud();
        }
    }

    @Override
    protected class_2394 method_7467() {
        return class_2398.field_28013;
    }

    @Override
    protected float method_7466() {
        return 1.0f;
    }

    @Override
    protected boolean method_7468() {
        return false;
    }


}
